@@ -16,7 +16,9 @@ from pydelica.solutions import SolutionHandler
 
 
 class Session:
-    def __init__(self, log_level: OMLogLevel = OMLogLevel.NORMAL) -> None:
+    def __init__(
+        self,
+        log_level: OMLogLevel = OMLogLevel.NORMAL) -> None:
         """Session object which handles model runs.
 
         This class is used to initiate model runs, building the models and
@@ -36,10 +38,27 @@ class Session:
             self._logger.setLevel(logging.DEBUG)
         self._compiler = Compiler()
         self._log_level = log_level
+        self._session_directory = os.getcwd()
         self._assert_fail_level = 'error'
 
-    def use_library(self, library_name: str, library_version: str = "") -> None:
-        self._compiler._library.use_library(library_name, library_version)
+    def use_library(
+        self,
+        library_name: str,
+        library_version: str = "",
+        library_directory: str = ""
+        ) -> None:
+        """Specify version of a library to use
+
+        Parameters
+        ----------
+        library_name : str
+            name of the Modelica library
+        library_version : str, optional
+            semantic version number, by default latest
+        library_directory : str, optional
+            location of library on system, by default OM default paths
+        """
+        self._compiler._library.use_library(library_name, library_version, library_directory)
 
     def fail_on_assert_level(self, assert_level: str) -> None:
         """Change assertion level on which model execution should fail
@@ -56,12 +75,13 @@ class Session:
         assert_level : str
             new level of assertion to trigger failure
         """
-        if assert_level not in ['info', 'warning', 'error', 'never']:
+        if assert_level in {'info', 'warning', 'error', 'debug', 'never'}:
+            self._assert_fail_level = assert_level
+        else:
             raise pde.UnknownOptionError(
                 f"Cannot set program fail assertion trigger to {assert_level}, "
                 "not a valid option"
             )
-        self._assert_fail_level = assert_level
 
 
     def build_model(
@@ -69,17 +89,41 @@ class Session:
         modelica_source_file: str,
         model_addr: str = None,
         extra_models: Optional[List[str]] = None,
+        c_source_dir: str = None,
         update_input_paths_to: str = None,
     ):
+        """Build a Modelica model from a source file
+
+        Parameters
+        ----------
+        modelica_source_file : str
+            Modelica source file to compile
+        model_addr : str, optional
+            address of model within source file, else default
+        extra_models : Optional[List[str]], optional
+            additional models required for compile, by default None
+        c_source_dir : str, optional
+            directory containing any additional required C sources, by default None
+        update_input_paths_to : str, optional
+            update input paths within model to another location, by default None
+
+        Raises
+        ------
+        pde.ModelicaFileGenerationError
+            if the XML parameter file was not generated
+        RuntimeError
+            If model compilation failed
+        """
         self._logger.debug(
             "Building model %sfrom file '%s'",
             model_addr + " " if model_addr else "",
             modelica_source_file,
         )
         _binary_loc = self._compiler.compile(
-            modelica_source_file,
-            model_addr,
-            extra_models
+            modelica_source_file=modelica_source_file,
+            model_addr=model_addr,
+            extra_models=extra_models,
+            c_source_dir=c_source_dir
         )
         _xml_files = glob.glob(os.path.join(_binary_loc, "*.xml"))
 
@@ -114,9 +158,7 @@ class Session:
                 "Located compiled binary '%s'", self._binaries[_model_name]
             )
 
-            self._solutions[_model_name] = SolutionHandler(
-                os.path.abspath(_binary_loc)
-            )
+            self._solutions[_model_name] = SolutionHandler(self._session_directory)
 
             self._logger.debug(
                 "Extracting default simulation options for model '%s' from XML file",
@@ -216,7 +258,7 @@ class Session:
         """
         if not model_name:
             model_name = list(self._binaries.keys())[0]
-        if not model_name in self._simulation_opts:
+        if model_name not in self._simulation_opts:
             raise pde.UnknownModelError(model_name)
         return self._simulation_opts[model_name]
 
@@ -267,7 +309,7 @@ class Session:
                 f" for parameter '{param_name}'"
             )
         self._logger.debug(
-            "Searching for parameter '%s' and assigning new value"
+            "Searching for parameter '%s' and assigning new value", param_name
         )
         for model in self._model_parameters:
             if param_name in self._model_parameters[model]:
@@ -326,12 +368,10 @@ class Session:
         # Write parameters to the XML file read by the binary
         self._model_parameters[model_name].write_params()
 
-        _current_dir = os.getcwd()
         _binary_dir = os.path.dirname(self._binaries[model_name])
-        os.chdir(_binary_dir)
 
         _args = [
-            os.path.join(".", os.path.basename(self._binaries[model_name]))
+            self._binaries[model_name], f'-inputPath={_binary_dir}'
         ]
 
         if not os.path.exists(self._binaries[model_name]):
@@ -357,7 +397,7 @@ class Session:
             _run_sim.stdout,
             self._assert_fail_level
         )
-        os.chdir(_current_dir)
+
         self._solutions[model_name].retrieve_session_solutions()
 
     def _set_output_to_csv(self):
