@@ -28,7 +28,7 @@ class Compiler:
         """
         self._logger = logging.getLogger("PyDelica.Compiler")
         self._environment = os.environ.copy()
-        self._library = LibrarySetup(open_modelica_library_path)
+        self._library = LibrarySetup()
         if "OPENMODELICAHOME" in os.environ:
             _omc_cmd = "omc.exe" if platform.system() == "Windows" else "omc"
             self._omc_binary = os.path.join(
@@ -61,6 +61,7 @@ class Compiler:
         self,
         modelica_source_file: str,
         model_addr: str = None,
+        c_source_dir: str = None,
         extra_models: List[str] = None
     ) -> str:
         """Compile Modelica source file
@@ -71,6 +72,8 @@ class Compiler:
             Modelica source file to compile
         model_addr : str, optional
             Model within source file to compile, default is first found
+        c_source_dir : str, optional
+            directory containing any additional required C sources
         extra_models: List[str], optional
             Additional other model dependencies
 
@@ -79,30 +82,64 @@ class Compiler:
         str
             location of output binary
         """
+        _temp_source_dir = tempfile.mkdtemp()
+        _temp_build_dir = tempfile.mkdtemp()
 
-        _temp_dir = tempfile.mkdtemp()
+        # Check if there is a 'Resources/Include' directory in the same
+        # location as the Modelica script
 
-        _current_wd = os.getcwd()
+        _candidate_c_inc = os.path.join(
+            os.path.dirname(modelica_source_file),
+            "Resources",
+            "Include"
+        )
 
+        if os.path.exists(_candidate_c_inc) and not c_source_dir:
+            c_source_dir = _candidate_c_inc
+
+        if c_source_dir:
+            self._prepare_c_incls(c_source_dir, _temp_source_dir)
         modelica_source_file = os.path.abspath(modelica_source_file)
 
+        # Copy sources to a temporary source location
+        self._logger.debug(
+            "Copying sources to temporary directory '%s'",
+            _temp_source_dir
+        )
+        _temp_model_source = os.path.join(
+            _temp_source_dir,
+            os.path.basename(modelica_source_file)
+        )
+        shutil.copy(modelica_source_file,_temp_model_source)
+
         if not os.path.exists(modelica_source_file):
             raise FileNotFoundError(
                 f"Could not compile Modelica file '{modelica_source_file}',"
                 " file does not exist"
             )
 
-        _args = [self._omc_binary, "-s", modelica_source_file]
+        _args = [self._omc_binary, "-s", _temp_model_source]
 
         if extra_models:
             for model in extra_models:
-                model = os.path.join(os.path.dirname(modelica_source_file), model)
-                if not os.path.exists(model):
+                _orig_model = os.path.join(
+                    os.path.dirname(modelica_source_file),
+                    model
+                )
+                if not os.path.exists(_orig_model):
                     raise FileNotFoundError(
                         f"Could not compile supplementary Modelica file '{model}',"
                         " file does not exist"
                     )
-                _args.append(model)
+                _temp_model_source = os.path.join(
+                    _temp_source_dir,
+                    os.path.basename(model)
+                )
+                shutil.copy(
+                    _orig_model,
+                    _temp_model_source
+                )
+                _args.append(_temp_model_source)
 
         _args.append("Modelica")
 
@@ -116,8 +153,6 @@ class Compiler:
 
         self._logger.debug(f"Executing Command: {_cmd_str}")
 
-        os.chdir(_temp_dir)
-
         _gen = None
 
         # Disable environment setting on Windows as it does not work at present
@@ -135,6 +170,7 @@ class Compiler:
                 stdout=subprocess.PIPE,
                 text=True,
                 env=_environ,
+                cwd=_temp_build_dir
             )
 
             pde.parse_error_string_compiler(_gen.stdout, _gen.stderr)
@@ -162,16 +198,16 @@ class Compiler:
         if _gen and _gen.stderr:
             self._logger.error(_gen.stderr)
 
-        _make_file = glob.glob(os.path.join(_temp_dir, "*.makefile"))
+        _make_file = glob.glob(os.path.join(_temp_build_dir, "*.makefile"))
 
         if not _make_file:
             self._logger.error(
                 "Output directory contents [%s]: %s",
-                _temp_dir,
-                os.listdir(_temp_dir),
+                _temp_build_dir,
+                os.listdir(_temp_build_dir),
             )
             raise pde.ModelicaFileGenerationError(
-                f"Failed to find a Makefile in the directory: {_temp_dir}, "
+                f"Failed to find a Makefile in the directory: {_temp_build_dir}, "
                 "Modelica failed to generated required files."
             )
 
@@ -197,9 +233,7 @@ class Compiler:
             ]
 
         elif not shutil.which("make"):
-            raise pde.BinaryNotFoundError(
-                f"Could not find GNU-Make on this system"
-            )
+            raise pde.BinaryNotFoundError('Could not find GNU-Make on this system')
         else:
             _make_cmd = shutil.which("make")
             _build_cmd = [_make_cmd, "-f", _make_file]
@@ -213,6 +247,7 @@ class Compiler:
             stdout=subprocess.PIPE,
             text=True,
             env=self._environment,
+            cwd=_temp_build_dir
         )
 
         try:
@@ -227,6 +262,15 @@ class Compiler:
         if _gen.stderr:
             self._logger.error(_build.stderr)
 
-        os.chdir(_current_wd)
+        return _temp_build_dir
 
-        return _temp_dir
+    def _prepare_c_incls(self, c_source_dir: str, _temp_dir: str):
+        self._logger.debug("Checking for C sources in '%s'", c_source_dir)
+        _c_sources = glob.glob(os.path.join(c_source_dir, '*.c'))
+        _c_sources += glob.glob(os.path.join(c_source_dir, '*.C'))
+        _include = os.path.join(_temp_dir, "Resources", "Include")
+        os.makedirs(_include)
+        for source in _c_sources:
+            _file_name = os.path.basename(source)
+            self._logger.debug("Found '%s'", _file_name)
+            shutil.copy(source, os.path.join(_include, _file_name))
