@@ -63,7 +63,7 @@ class Model(collections.abc.MutableMapping):
         elif om_type == 'Real':
             return float, float(value) if value else value
         elif om_type == 'String':
-            return str, value if value else value
+            return str, value or value
         else:
             #TODO: Definitely other types
             return None, value
@@ -91,10 +91,11 @@ class Model(collections.abc.MutableMapping):
 
             _name = item.attrib['name']
 
-            if not self._parameters[_name]['value']:
-                # We want zeros passed but nothing else
-                if self._parameters[_name]['value'] != 0:
-                    continue
+            if (
+                not self._parameters[_name]['value']
+                and self._parameters[_name]['value'] != 0
+            ):
+                continue
 
             # Booleans are lower case in the XML
             if self._parameters[_name]['type'] == bool:
